RecentTracksRequestBuilder

Struct RecentTracksRequestBuilder 

pub struct RecentTracksRequestBuilder { /* private fields */ }
Builder for recent tracks requests.

Implementations

Source

impl RecentTracksRequestBuilder

pub const fn since(self, timestamp: i64) -> Self

Fetch tracks from this timestamp onwards.

Arguments
  • timestamp - Unix timestamp in seconds (not milliseconds) since January 1, 1970 UTC
Example
// Fetch tracks since January 1, 2024 00:00:00 UTC
let tracks = client.recent_tracks()
    .builder("username")
    .since(1704067200)
    .fetch()
    .await?;
pub const fn between(self, from: i64, to: i64) -> Self

Fetch tracks between two timestamps.

Arguments
  • from - Start Unix timestamp in seconds (not milliseconds) since January 1, 1970 UTC
  • to - End Unix timestamp in seconds (not milliseconds) since January 1, 1970 UTC
Example
// Fetch tracks between January 1, 2024 and February 1, 2024 (UTC)
let tracks = client.recent_tracks()
    .builder("username")
    .between(1704067200, 1706745600)
    .fetch()
    .await?;
pub fn on_progress( self, callback: impl Fn(u32, u32) + Send + Sync + 'static, ) -> Self

Register a progress callback invoked with (fetched, total) after each batch.

pub async fn fetch(self) -> Result<TrackList<RecentTrack>>

Fetch the tracks.

Errors

Returns an error if:

  • The HTTP request fails or the response cannot be parsed
  • The date range is invalid (to <= from when both timestamps are set)
pub async fn check_currently_playing(self) -> Result<Option<RecentTrack>>

Check if the user is currently playing a track.

Errors

Returns an error if the HTTP request fails or the response cannot be parsed.

Returns
  • Result<Option<RecentTrack>> - The currently playing track if any
Source

impl RecentTracksRequestBuilder

pub async fn fetch_extended(self) -> Result<TrackList<RecentTrackExtended>>

Fetch tracks with extended information.

Errors

Returns an error if:

  • The HTTP request fails or the response cannot be parsed
  • The date range is invalid (to <= from when both timestamps are set)
pub async fn fetch_extended_and_save( self, format: FileFormat, filename_prefix: &str, ) -> Result<String>

Fetch tracks with extended information and save them to a file.

Arguments
  • format - The file format to save the tracks in
  • filename_prefix - Prefix for the generated filename
Errors

Returns an error if the HTTP request fails, response cannot be parsed, or file cannot be saved.

Returns
  • Result<String> - The filename of the saved file
pub async fn fetch_extended_and_update(self, file_path: &str) -> Result<usize>

Fetch only extended tracks newer than the most recent entry in an existing file and prepend them to it. If the file does not exist, all tracks are fetched and the file is created.

Arguments
  • file_path - Path to the file to update (or create)
Errors

Returns an error if the HTTP request fails, the response cannot be parsed, or the file cannot be read or written.

Returns
  • Result<usize> - Number of new tracks prepended