LovedTracksRequestBuilder

Struct LovedTracksRequestBuilder 

pub struct LovedTracksRequestBuilder { /* private fields */ }
Builder for loved tracks requests

Implementations

Source

impl LovedTracksRequestBuilder

pub fn limit(self, limit: u32) -> Self

Set the maximum number of tracks to fetch

pub fn unlimited(self) -> Self

Fetch all available tracks (no limit)

pub async fn fetch(self) -> Result<Vec<LovedTrack>>

Fetch the tracks

Errors

Returns an error if the HTTP request fails or the response cannot be parsed.

pub async fn fetch_and_save( self, format: FileFormat, filename_prefix: &str, ) -> Result<String>

Fetch tracks and save them to a file

Arguments
  • format - The file format to save the tracks in
  • filename_prefix - Prefix for the generated filename
Errors

Returns an error if the HTTP request fails, response cannot be parsed, or file cannot be saved.

Returns
  • Result<String> - The filename of the saved file
pub async fn analyze(self, threshold: usize) -> Result<TrackStats>

Analyze tracks and return statistics

Arguments
  • threshold - Threshold for counting tracks with plays below this number
Errors

Returns an error if the HTTP request fails or the response cannot be parsed.

Returns
  • Result<crate::analytics::TrackStats> - Analysis results
pub async fn analyze_and_print(self, threshold: usize) -> Result<()>

Analyze tracks and print statistics

Arguments
  • threshold - Threshold for counting tracks with plays below this number
Errors

Returns an error if the HTTP request fails or the response cannot be parsed.