pub struct RecentTracksRequestBuilder { /* private fields */ }Expand description
Builder for recent tracks requests
Implementations
Sourceimpl RecentTracksRequestBuilder
impl RecentTracksRequestBuilder
Sourcepub async fn fetch(self) -> Result<Vec<RecentTrack>>
pub async fn fetch(self) -> Result<Vec<RecentTrack>>
Fetch the tracks
Errors
Returns an error if:
- The HTTP request fails or the response cannot be parsed
- The date range is invalid (to <= from)
Sourcepub async fn fetch_extended(self) -> Result<Vec<RecentTrackExtended>>
pub async fn fetch_extended(self) -> Result<Vec<RecentTrackExtended>>
Fetch tracks with extended information
Errors
Returns an error if:
- The HTTP request fails or the response cannot be parsed
- The date range is invalid (to <= from)
Sourcepub async fn fetch_and_save(
self,
format: FileFormat,
filename_prefix: &str,
) -> Result<String>
pub async fn fetch_and_save( self, format: FileFormat, filename_prefix: &str, ) -> Result<String>
Fetch tracks and save them to a file
Arguments
format- The file format to save the tracks infilename_prefix- Prefix for the generated filename
Errors
Returns an error if the HTTP request fails, response cannot be parsed, or file cannot be saved.
Returns
Result<String>- The filename of the saved file
Sourcepub async fn fetch_extended_and_save(
self,
format: FileFormat,
filename_prefix: &str,
) -> Result<String>
pub async fn fetch_extended_and_save( self, format: FileFormat, filename_prefix: &str, ) -> Result<String>
Fetch tracks with extended information and save them to a file
Arguments
format- The file format to save the tracks infilename_prefix- Prefix for the generated filename
Errors
Returns an error if the HTTP request fails, response cannot be parsed, or file cannot be saved.
Returns
Result<String>- The filename of the saved file
Sourcepub async fn analyze(self, threshold: usize) -> Result<TrackStats>
pub async fn analyze(self, threshold: usize) -> Result<TrackStats>
Sourcepub async fn analyze_and_print(self, threshold: usize) -> Result<()>
pub async fn analyze_and_print(self, threshold: usize) -> Result<()>
Sourcepub async fn check_currently_playing(self) -> Result<Option<RecentTrack>>
pub async fn check_currently_playing(self) -> Result<Option<RecentTrack>>